"use strict";
var JsObject = (function () {
    /**
     * Class for an object.
     * @param {Interpreter.Object} parent Parent constructor function.
     * @constructor
     */
    function JsObject(parent) {
        /**
         * @type {string}
         */
        this.type = 'object';
        /**
         * @type {Interpreter.Object}
         */
        this.parent = null;
        /**
         * @type {boolean}
         */
        this.isPrimitive = false;
        /**
         * @type {number|string|boolean|undefined|!RegExp}
         */
        this.data = undefined;
        this.notConfigurable = Object.create(null);
        this.notEnumerable = Object.create(null);
        this.notWritable = Object.create(null);
        this.getter = Object.create(null);
        this.setter = Object.create(null);
        this.properties = Object.create(null);
        this.parent = parent;
    }
    ;
    /**
     * Convert this object into a boolean.
     * @return {boolean} Boolean value.
     */
    JsObject.prototype.toBoolean = function () {
        return true;
    };
    ;
    /**
     * Convert this object into a number.
     * @return {number} Number value.
     */
    JsObject.prototype.toNumber = function () {
        return Number(this.data === undefined ? this.toString() : this.data);
    };
    ;
    /**
     * Convert this object into a string.
     * @return {string} String value.
     * @override
     */
    JsObject.prototype.toString = function () {
        return this.data === undefined ? ('[' + this.type + ']') : String(this.data);
    };
    ;
    /**
     * Return the object value.
     * @return {*} Value.
     * @override
     */
    JsObject.prototype.valueOf = function () {
        return this.data === undefined ? this : this.data;
    };
    ;
    return JsObject;
}());
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = JsObject;
//# sourceMappingURL=JsObject.js.map