"use strict";
var Primitive = (function () {
    /**
     * Class for a number, string, boolean, null, or undefined.
     * @param {number|string|boolean|null|undefined} data Primitive value.
     * @param {!Interpreter} interpreter The JS Interpreter to bind to.
     * @constructor
     */
    function Primitive(data, interpreter) {
        /**
         * @type {number|string|boolean|null|undefined}
         */
        this.data = undefined;
        /**
         * @type {string}
         */
        this.type = 'undefined';
        /**
         * @type {Function}
         */
        this.parent = null;
        /**
         * @type {boolean}
         */
        this.isPrimitive = true;
        var type = typeof data;
        this.data = data;
        this.type = type;
        if (type == 'number') {
            this.parent = interpreter.NUMBER;
        }
        else if (type == 'string') {
            this.parent = interpreter.STRING;
        }
        else if (type == 'boolean') {
            this.parent = interpreter.BOOLEAN;
        }
    }
    ;
    /**
     * Convert this primitive into a boolean.
     * @return {boolean} Boolean value.
     */
    Primitive.prototype.toBoolean = function () {
        return Boolean(this.data);
    };
    ;
    /**
     * Convert this primitive into a number.
     * @return {number} Number value.
     */
    Primitive.prototype.toNumber = function () {
        return Number(this.data);
    };
    ;
    /**
     * Convert this primitive into a string.
     * @return {string} String value.
     * @override
     */
    Primitive.prototype.toString = function () {
        return String(this.data);
    };
    ;
    /**
     * Return the primitive value.
     * @return {number|string|boolean|null|undefined} Primitive value.
     * @override
     */
    Primitive.prototype.valueOf = function () {
        return this.data;
    };
    ;
    return Primitive;
}());
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = Primitive;
//# sourceMappingURL=Primitive.js.map